@@ -11,11 +11,12 @@ from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey
 
 class PrivateKey:
     "class to extract various pieces of information from private-key file"
+
     def __init__(
         self,
         private_key_file: Path,
         pass_phrase: Optional[str] = None,
-        pass_phrase_var: Optional[str] = "SNOWSQL_PRIVATE_KEY_PASSPHRASE"
+        pass_phrase_var: Optional[str] = "SNOWSQL_PRIVATE_KEY_PASSPHRASE",
     ):
         if not private_key_file.is_file():
             raise FileNotFoundError(f"Invalid private Key file '{private_key_file}'")
@@ -27,17 +28,13 @@ class PrivateKey:
     def key(self) -> RSAPrivateKey:
         with self.private_key_file.open("rb") as fh:
             return Serde.load_pem_private_key(  # type: ignore
-                fh.read(),
-                password=self.pass_phrase.encode() if self.pass_phrase is not None else None,
-                backend=default_backend()
+                fh.read(), password=self.pass_phrase.encode() if self.pass_phrase is not None else None, backend=default_backend()
             )
 
     @property
     def pri_bytes(self) -> bytes:
         return self.key.private_bytes(
-            encoding=Serde.Encoding.DER,
-            format=Serde.PrivateFormat.PKCS8,
-            encryption_algorithm=Serde.NoEncryption()
+            encoding=Serde.Encoding.DER, format=Serde.PrivateFormat.PKCS8, encryption_algorithm=Serde.NoEncryption()
         )
 
     @property
